@@ -2,6 +2,7 @@
  * PROJECT: GEM-Tools library
  * FILE: gt_input_sam_parser.h
  * DATE: 17/07/2012
+ * AUTHOR(S): Santiago Marco-Sola <santiagomsola@gmail.com>
  * DESCRIPTION: // TODO
  */
 
@@ -14,15 +15,17 @@
 #include "gt_alignment_utils.h"
 #include "gt_template_utils.h"
 
+#include "gt_sequence_archive.h"
+
 #include "gt_input_file.h"
 #include "gt_buffered_input_file.h"
 #include "gt_input_parser.h"
-#include "gt_input_fastq_parser.h"
+#include "gt_input_fasta_parser.h"
 
 // Codes gt_status
-#define GT_ISP_OK 1
-#define GT_ISP_FAIL -1
-#define GT_ISP_EOF 0
+#define GT_ISP_OK   GT_STATUS_OK
+#define GT_ISP_FAIL GT_STATUS_FAIL
+#define GT_ISP_EOF  0
 
 /*
  * Parsing error/state codes
@@ -37,7 +40,6 @@
 #define GT_ISP_PE_SAM_UNMAPPED_XA 21
 /* PairedEnd Parsing */
 #define GT_ISP_PE_WRONG_NUM_XA 30
-//#define GT_ISP_PE_WRONG_END_POS 31
 #define GT_ISP_PE_UNSOLVED_PENDING_MAPS 32
 
 /*
@@ -62,11 +64,20 @@
  */
 #define GT_ATTR_SAM_FLAGS "SAM_FLAGS"
 
+typedef struct {
+  bool sam_soap_style;
+} gt_sam_parser_attr;
+
+#define GT_SAM_PARSER_ATTR_DEFAULT { .sam_soap_style=false }
+GT_INLINE void gt_input_sam_parser_attributes_reset_defaults(gt_sam_parser_attr* const sam_parser_attr);
+GT_INLINE void gt_input_sam_parser_attributes_set_soap_compilant(gt_sam_parser_attr* const sam_parser_attr);
+
+GT_INLINE gt_sam_parser_attr* gt_sam_parser_attr_new(bool const sam_soap_style);
 /*
  * SAM File basics
  */
 GT_INLINE bool gt_input_file_test_sam(
-    gt_input_file* const input_file,gt_sam_headers* const sam_headers,const bool show_errors); // TODO: Install it in gt_input_file.h
+    gt_input_file* const input_file,gt_sam_headers* const sam_headers,const bool show_errors);
 GT_INLINE void gt_input_sam_parser_prompt_error(
     gt_buffered_input_file* const buffered_map_input,
     uint64_t line_num,uint64_t column_pos,const gt_status error_code);
@@ -75,8 +86,9 @@ GT_INLINE void gt_input_sam_parser_next_record(gt_buffered_input_file* const buf
 /*
  * High Level Parsers
  */
-GT_INLINE gt_status gt_input_sam_parser_get_template(gt_buffered_input_file* const buffered_map_input,gt_template* const template);
-GT_INLINE gt_status gt_input_sam_parser_get_soap_template(gt_buffered_input_file* const buffered_sam_input,gt_template* const template);
-GT_INLINE gt_status gt_input_sam_parser_get_alignment(gt_buffered_input_file* const buffered_map_input,gt_alignment* const alignment);
+GT_INLINE gt_status gt_input_sam_parser_get_template(
+    gt_buffered_input_file* const buffered_map_input,gt_template* const template,gt_sam_parser_attr* const sam_parser_attr);
+GT_INLINE gt_status gt_input_sam_parser_get_alignment(
+    gt_buffered_input_file* const buffered_map_input,gt_alignment* const alignment,gt_sam_parser_attr* const sam_parser_attr);
 
 #endif /* GT_INPUT_SAM_PARSER_H_ */
