@@ -2,6 +2,7 @@
  * PROJECT: GEM-Tools library
  * FILE: gt_template.c
  * DATE: 01/06/2012
+ * AUTHOR(S): Santiago Marco-Sola <santiagomsola@gmail.com>
  * DESCRIPTION: Data structure modeling sequences' templates.
  *   That is, set of alignments and relationships between their maps.
  */
@@ -27,23 +28,23 @@ GT_INLINE gt_template* gt_template_new() {
   template->mmaps = gt_vector_new(GT_TEMPLATE_NUM_INITIAL_MMAPS,sizeof(gt_map*));
   template->mmaps_attributes = gt_vector_new(GT_TEMPLATE_NUM_INITIAL_MMAPS,sizeof(gt_mmap_attributes));
   template->maps_txt = NULL;
-  template->attributes = gt_shash_new();
+  template->attributes = gt_attribute_new();
   return template;
 }
 GT_INLINE void gt_template_clear_handler(gt_template* const template) {
   GT_TEMPLATE_CHECK(template);
   gt_string_clear(template->tag);
   template->maps_txt = NULL;
-  gt_shash_clean(template->attributes,true,true);
+  gt_attribute_clear(template->attributes);
 }
 GT_INLINE void gt_template_clear(gt_template* const template,const bool delete_alignments) {
   GT_TEMPLATE_CHECK(template);
   if (delete_alignments) {
     gt_template_delete_blocks(template);
   }
-  gt_vector_clean(template->counters);
-  gt_vector_clean(template->mmaps);
-  gt_vector_clean(template->mmaps_attributes);
+  gt_vector_clear(template->counters);
+  gt_vector_clear(template->mmaps);
+  gt_vector_clear(template->mmaps_attributes);
   gt_template_clear_handler(template);
 }
 GT_INLINE void gt_template_clear_alignments(gt_template* const template) {
@@ -60,20 +61,40 @@ GT_INLINE void gt_template_delete(gt_template* const template) {
   gt_vector_delete(template->counters);
   gt_vector_delete(template->mmaps);
   gt_vector_delete(template->mmaps_attributes);
-  gt_shash_delete(template->attributes,true,true);
+  gt_attribute_delete(template->attributes);
   free(template);
 }
 
 /*
  * Accessors
  */
+GT_INLINE int64_t gt_template_get_pair(gt_template* const template){
+  GT_TEMPLATE_CHECK(template);
+  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
+    return gt_alignment_get_pair(alignment);
+  } GT_TEMPLATE_END_REDUCTION;
+  return *gt_shash_get(template->attributes,GT_TAG_PAIR,int64_t);
+}
 GT_INLINE char* gt_template_get_tag(gt_template* const template) {
   GT_TEMPLATE_CHECK(template);
+  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
+    return gt_alignment_get_tag(alignment);
+  } GT_TEMPLATE_END_REDUCTION;
   return gt_string_get_string(template->tag);
 }
+GT_INLINE gt_string* gt_template_get_string_tag(gt_template* const template) {
+  GT_TEMPLATE_CHECK(template);
+  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
+    return gt_alignment_get_string_tag(alignment);
+  } GT_TEMPLATE_END_REDUCTION;
+  return template->tag;
+}
 GT_INLINE void gt_template_set_tag(gt_template* const template,char* const tag,const uint64_t length) {
   GT_TEMPLATE_CHECK(template);
   GT_NULL_CHECK(tag);
+  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
+    return gt_alignment_set_tag(alignment,tag,length);
+  } GT_TEMPLATE_END_REDUCTION;
   gt_string_set_nstring(template->tag,tag,length);
 }
 GT_INLINE uint64_t gt_template_get_total_length(gt_template* const template) {
@@ -110,19 +131,19 @@ GT_INLINE gt_alignment* gt_template_get_block_dyn(gt_template* const template,co
     gt_template_add_block(template,dynamic_allocated_alignment);
     return dynamic_allocated_alignment;
   } else {
-    gt_fatal_error(POSITION_OUT_OF_RANGE_INFO,(uint64_t)position,0ul,num_blocks-1);
+    gt_fatal_error(POSITION_OUT_OF_RANGE_INFO,(uint64_t)position,(uint64_t)0,num_blocks-1);
   }
 }
 GT_INLINE void gt_template_clear_blocks(gt_template* const template) {
   GT_TEMPLATE_CHECK(template);
-  gt_vector_clean(template->blocks);
+  gt_vector_clear(template->blocks);
 }
 GT_INLINE void gt_template_delete_blocks(gt_template* const template) {
   GT_TEMPLATE_CHECK(template);
   GT_VECTOR_ITERATE(template->blocks,alignment_it,alignment_pos,gt_alignment*) {
     gt_alignment_delete(*alignment_it);
   }
-  gt_vector_clean(template->blocks);
+  gt_vector_clear(template->blocks);
 }
 /* Counters */
 GT_INLINE gt_vector* gt_template_get_counters_vector(gt_template* const template) {
@@ -149,88 +170,68 @@ GT_INLINE uint64_t gt_template_get_num_counters(gt_template* const template) {
 }
 GT_INLINE uint64_t gt_template_get_counter(gt_template* const template,const uint64_t stratum) {
   GT_TEMPLATE_CHECK(template);
-  gt_fatal_check(stratum==0,COUNTERS_POS_STRATUM);
   GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
     return gt_alignment_get_counter(alignment,stratum);
   } GT_TEMPLATE_END_REDUCTION;
-  return *gt_vector_get_elm(template->counters,stratum-1,uint64_t);
+  return *gt_vector_get_elm(template->counters,stratum,uint64_t);
 }
 GT_INLINE void gt_template_dynamically_allocate_counter(gt_template* const template,const uint64_t stratum) {
   GT_TEMPLATE_CHECK(template);
-  gt_fatal_check(stratum==0,COUNTERS_POS_STRATUM);
-  gt_vector_reserve(template->counters,stratum,true);
-  if (gt_vector_get_used(template->counters)<stratum) {
-    gt_vector_set_used(template->counters,stratum);
+  register const uint64_t used_strata = stratum+1;
+  gt_vector_reserve(template->counters,used_strata,true);
+  if (gt_vector_get_used(template->counters)<used_strata) {
+    gt_vector_set_used(template->counters,used_strata);
   }
 }
 GT_INLINE void gt_template_inc_counter(gt_template* const template,const uint64_t stratum) {
   GT_TEMPLATE_CHECK(template);
-  gt_fatal_check(stratum==0,COUNTERS_POS_STRATUM);
   GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
     gt_alignment_inc_counter(alignment,stratum);
   } GT_TEMPLATE_END_REDUCTION__RETURN;
   gt_template_dynamically_allocate_counter(template,stratum);
-  ++(*gt_vector_get_elm(template->counters,stratum-1,uint64_t));
+  ++(*gt_vector_get_elm(template->counters,stratum,uint64_t));
 }
 GT_INLINE void gt_template_dec_counter(gt_template* const template,const uint64_t stratum) {
   GT_TEMPLATE_CHECK(template);
-  gt_fatal_check(stratum==0,COUNTERS_POS_STRATUM);
   GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
     gt_alignment_dec_counter(alignment,stratum);
   } GT_TEMPLATE_END_REDUCTION__RETURN;
   gt_template_dynamically_allocate_counter(template,stratum);
-  --(*gt_vector_get_elm(template->counters,stratum-1,uint64_t));
+  --(*gt_vector_get_elm(template->counters,stratum,uint64_t));
 }
 GT_INLINE void gt_template_set_counter(gt_template* const template,const uint64_t stratum,const uint64_t value) {
   GT_TEMPLATE_CHECK(template);
-  gt_fatal_check(stratum==0,COUNTERS_POS_STRATUM);
   GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
     gt_alignment_set_counter(alignment,stratum,value);
   } GT_TEMPLATE_END_REDUCTION__RETURN;
   gt_template_dynamically_allocate_counter(template,stratum);
-  *gt_vector_get_elm(template->counters,stratum-1,uint64_t) = value;
+  *gt_vector_get_elm(template->counters,stratum,uint64_t) = value;
 }
 
-/*
- * Attribute accessors
- */
-GT_INLINE void* gt_template_get_attr(
-    gt_template* const template,char* const attribute_id) {
-  GT_TEMPLATE_CHECK(template);
-  GT_NULL_CHECK(attribute_id);
-  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
-    return gt_alignment_get_attr(alignment,attribute_id);
-  } GT_TEMPLATE_END_REDUCTION;
-  return gt_attribute_get(template->attributes,attribute_id);
-}
-GT_INLINE void gt_template_set_attr(
-    gt_template* const template,char* const attribute_id,
-    void* const attribute,const size_t element_size) {
-  GT_TEMPLATE_CHECK(template);
-  GT_NULL_CHECK(attribute_id);
-  GT_NULL_CHECK(attribute);
-  GT_ZERO_CHECK(element_size);
-  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
-    gt_alignment_set_attr(alignment,attribute_id,attribute,element_size);
-  } GT_TEMPLATE_END_REDUCTION__RETURN;
-  // Insert attribute
-  gt_attribute_set(template->attributes,attribute_id,attribute,element_size);
-}
 /*
  * Predefined attributes
  */
-GT_INLINE uint64_t gt_template_get_mcs(gt_template* const template) { // FIXME: reduce
+GT_INLINE uint64_t gt_template_get_mcs(gt_template* const template) {
   GT_TEMPLATE_CHECK(template);
-  register uint64_t* mcs = gt_template_get_attribute(template,GT_ATTR_MAX_COMPLETE_STRATA,uint64_t);
+  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
+    return gt_alignment_get_mcs(alignment);
+  } GT_TEMPLATE_END_REDUCTION;
+  register uint64_t* mcs = gt_attribute_get(template->attributes,GT_ATTR_MAX_COMPLETE_STRATA);
   if (mcs == NULL) return UINT64_MAX;
   return *mcs;
 }
 GT_INLINE void gt_template_set_mcs(gt_template* const template,uint64_t max_complete_strata) {
   GT_TEMPLATE_CHECK(template);
-  gt_template_set_attribute(template,GT_ATTR_MAX_COMPLETE_STRATA,&max_complete_strata,uint64_t);
+  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
+    gt_alignment_set_mcs(alignment,max_complete_strata);
+  } GT_TEMPLATE_END_REDUCTION__RETURN;
+  gt_attribute_set(template->attributes,GT_ATTR_MAX_COMPLETE_STRATA,&max_complete_strata,uint64_t);
 }
 GT_INLINE bool gt_template_has_qualities(gt_template* const template) {
   GT_TEMPLATE_CHECK(template);
+  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
+    return gt_alignment_has_qualities(alignment);
+  } GT_TEMPLATE_END_REDUCTION;
   register const uint64_t num_blocks = gt_template_get_num_blocks(template);
   register uint64_t i;
   for (i=0;i<num_blocks;++i) {
@@ -241,13 +242,19 @@ GT_INLINE bool gt_template_has_qualities(gt_template* const template) {
 }
 GT_INLINE bool gt_template_get_not_unique_flag(gt_template* const template) {
   GT_TEMPLATE_CHECK(template);
-  register bool* const not_unique_flag = gt_template_get_attribute(template,GT_ATTR_NOT_UNIQUE,bool);
+  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
+    return gt_alignment_get_not_unique_flag(alignment);
+  } GT_TEMPLATE_END_REDUCTION;
+  register bool* const not_unique_flag = gt_attribute_get(template->attributes,GT_ATTR_NOT_UNIQUE);
   if (not_unique_flag==NULL) return false;
   return *not_unique_flag;
 }
 GT_INLINE void gt_template_set_not_unique_flag(gt_template* const template,bool is_not_unique) {
   GT_TEMPLATE_CHECK(template);
-  gt_template_set_attribute(template,GT_ATTR_NOT_UNIQUE,&is_not_unique,bool);
+  GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
+    gt_alignment_set_not_unique_flag(alignment,is_not_unique);
+  } GT_TEMPLATE_END_REDUCTION__RETURN;
+  gt_attribute_set(template->attributes,GT_ATTR_NOT_UNIQUE,&is_not_unique,bool);
 }
 
 /*
@@ -280,8 +287,8 @@ GT_INLINE void gt_template_clear_mmaps(gt_template* const template) {
   GT_TEMPLATE_IF_REDUCES_TO_ALINGMENT(template,alignment) {
     gt_alignment_clear_maps(alignment);
   } GT_TEMPLATE_END_REDUCTION__RETURN;
-  gt_vector_clean(template->mmaps);
-  gt_vector_clean(template->mmaps_attributes);
+  gt_vector_clear(template->mmaps);
+  gt_vector_clear(template->mmaps_attributes);
 }
 /* */
 GT_INLINE void gt_template_add_mmap(
@@ -411,11 +418,11 @@ GT_INLINE void gt_template_copy_handler(gt_template* template_dst,gt_template* c
   gt_string_copy(template_dst->tag,template_src->tag);
   template_dst->maps_txt = template_src->maps_txt;
   // Copy templates' attributes
-  template_dst->attributes = gt_shash_deep_copy(template_src->attributes);
+  gt_shash_copy(template_dst->attributes,template_src->attributes);
 }
 GT_INLINE void gt_template_copy_blocks(gt_template* template_dst,gt_template* const template_src,const bool copy_maps) {
   GT_TEMPLATE_CONSISTENCY_CHECK(template_src);
-  gt_vector_clean(template_dst->blocks);
+  gt_vector_clear(template_dst->blocks);
   register const uint64_t num_blocks = gt_template_get_num_blocks(template_src);
   register uint64_t i;
   for (i=0;i<num_blocks;++i) {
@@ -433,7 +440,7 @@ GT_INLINE gt_template* gt_template_copy(gt_template* const template,const bool c
   // Copy blocks
   gt_template_copy_blocks(template_cpy,template,copy_maps);
   // Copy mmaps
-  if (copy_maps && copy_mmaps) {
+  if (copy_maps && copy_mmaps && gt_template_get_num_blocks(template)>1) {
     // Copy counters
     gt_vector_copy(template_cpy->counters,template->counters);
     // Copy mmaps & mmaps_attributes
