@@ -66,9 +66,9 @@ log_output = LOG_NOTHING
 
 
 default_splice_consensus = [("GT", "AG")]
-extended_splice_consensus = [("GT", "AG"), 
+extended_splice_consensus = [("GT", "AG"),
     ("GC", "AG"),
-    ("ATATC", "A."), 
+    ("ATATC", "A."),
     ("GTATC", "AT")]
 
 
@@ -799,7 +799,8 @@ def score(input,
 
 def gem2sam(input, index=None, output=None,
     single_end=False, compact=False, threads=1,
-    quality=None, check_ids=True, add_length=True, consensus=None):
+    quality=None, check_ids=True, add_length=True, consensus=None,
+    exclude_header=False):
 
     if index is not None:
         index = _prepare_index_parameter(index, gem_suffix=True)
@@ -811,6 +812,8 @@ def gem2sam(input, index=None, output=None,
     ]
     if index is not None:
         gem_2_sam_p.extend(['-I', index])
+        if not exclude_header:
+            gem_2_sam_p.append("-l")
     if add_length is not None:
         gem_2_sam_p.append('-l')
 
@@ -850,6 +853,10 @@ def _check_samtools(command, threads=1, extend=None):
         p.extend(extend)
     return p
 
+def __is_parallel_samtools():
+    if __parallel_samtools is None:
+        _check_samtools("view", threads=2)
+    return __parallel_samtools
 
 def sam2bam(input, output=None, sorted=False, tmpdir=None, mapq=None, threads=1, sort_memory="768M"):
     sam2bam_p = _check_samtools("view", threads=threads, extend=["-S", "-b"])
@@ -861,6 +868,18 @@ def sam2bam(input, output=None, sorted=False, tmpdir=None, mapq=None, threads=1,
     tools = [sam2bam_p]
     out_name = output
     if sorted:
+        if not __is_parallel_samtools():
+            # check the memory paramters
+            try:
+                m = int(sort_memory)
+                if m < 128 * 1024 * 128:  # ugly but we assume you give it at least 128 mb
+                    sort_memory = 768 * 1024 * 1024
+                    if m < 1024 * 32:
+                        sort_memory = m * 1024 * 1024
+            except Exception, e:
+                # convert to default byte
+                sort_memory = 768 * 1024 * 1024
+
         bam_sort = _check_samtools("sort", threads=threads, extend=["-m", str(sort_memory), "-o", "-"])
         suffix = ""
         if output is not None:
