@@ -7,8 +7,8 @@ import gem
 from testfiles import testfiles
 
 def test_splice_consensus_conversion():
-    assert gem._prepare_splice_consensus_parameter(None) == '"GT"+"AG","CT"+"AC"'
-    assert gem._prepare_splice_consensus_parameter([("AA", "BB"), ("CC", "DD")]) == '"AA"+"BB","CC"+"DD"'
+    assert gem._prepare_splice_consensus_parameter(None) == 'GT+AG'
+    assert gem._prepare_splice_consensus_parameter([("AA", "BB"), ("CC", "DD")]) == 'AA+BB,CC+DD'
 
 
 def test_quality_parameter():
@@ -28,6 +28,6 @@ def test_index_parameter():
     assert gem._prepare_index_parameter(c(".gem"), False) == c("")
 
 
-@raises(ValueError)
+@raises(IOError)
 def test_index_parameter_checks_file():
-    gem._prepare_index_parameter("unknown_index", False)
\ No newline at end of file
+    gem._prepare_index_parameter("unknown_index", False)
